@@ -68,7 +68,7 @@ add_p <- function(x, ...) {
 #' #### Specified neither `add_p(group)` nor `add_p(adj.vars)`
 #'
 #' - `"wilcox.test"` when `by` variable has two levels and variable is continuous.
-#' - `"krustkal.test"` when `by` variable has more than two levels and variable is continuous.
+#' - `"kruskal.test"` when `by` variable has more than two levels and variable is continuous.
 #' - `"chisq.test.no.correct"` for categorical variables with all expected cell counts >=5,
 #'    and `"fisher.test"` for categorical variables with any expected cell count <5.
 #'
@@ -83,7 +83,7 @@ add_p <- function(x, ...) {
 #'
 #'  - `"ancova"` when variable is continuous and `by` variable has two levels.
 #'
-#' @examplesIf gtsummary:::is_pkg_installed("cardx", reference_pkg = "gtsummary") && gtsummary:::is_pkg_installed("broom", reference_pkg = "cardx")
+#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed("cardx") && gtsummary:::is_pkg_installed("broom", ref = "cardx")
 #' # Example 1 ----------------------------------
 #' trial |>
 #'   tbl_summary(by = trt, include = c(age, grade)) |>
@@ -269,7 +269,7 @@ calculate_and_add_test_results <- function(x, include, group = NULL, test.args,
         if (!is.null(lst_captured_results[["result"]])) return(lst_captured_results[["result"]]) # styler: off
         # otherwise, construct a {cards}-like object with error
         dplyr::tibble(
-          group1 = x$inputs$by,
+          group1 = switch(!is_empty(x$inputs$by), x$inputs$by),
           variable = variable,
           stat_name = switch(calling_fun,
                              "add_p" = "p.value",
