@@ -39,7 +39,7 @@
 #'     hide_ci = TRUE, hide_se = TRUE
 #'   ) |>
 #'   modify_header(estimate = "**Beta (95% CI)**") |>
-#'   modify_footnote(estimate = "CI = Confidence Interval", abbreviation = TRUE)
+#'   modify_abbreviation("CI = Confidence Interval")
 #'
 #' # Example 3 ----------------------------------
 #' # Use '  \n' to put a line break between beta and SE
@@ -49,7 +49,7 @@
 #'     pattern = "{estimate}{stars}  \n({std.error})"
 #'   ) |>
 #'   modify_header(estimate = "**Beta  \n(SE)**") |>
-#'   modify_footnote(estimate = "SE = Standard Error", abbreviation = TRUE) |>
+#'   modify_abbreviation("SE = Standard Error") |>
 #'   as_gt() |>
 #'   gt::fmt_markdown(columns = everything()) |>
 #'   gt::tab_style(
@@ -118,7 +118,7 @@ add_significance_stars <- function(x,
     unlist() |>
     paste(collapse = "; ")
 
-  x <- modify_footnote(x, any_of(pattern_cols[1]) ~ p_footnote)
+  x <- modify_footnote_header(x, footnote = p_footnote, columns = any_of(pattern_cols[1]))
 
   # adding stars column --------------------------------------------------------
   thresholds <- union(thresholds, 0L)
