@@ -4,7 +4,6 @@
 #' These functions assist with modifying the aesthetics/style of a table.
 #'
 #' - `modify_header()` update column headers
-#' - `modify_footnote()` update/add table footnotes
 #' - `modify_spanning_header()` update/add spanning headers
 #'
 #' The functions often require users to know the underlying column names.
@@ -13,20 +12,25 @@
 #' @param x (`gtsummary`)\cr
 #'   A gtsummary object
 #' @param ... [`dynamic-dots`][rlang::dyn-dots]\cr
-#'   Used to assign updates to headers,
-#'   spanning headers, and footnotes.
+#'   Used to assign updates to headers and spanning headers.
 #'
-#'   Use `modify_*(colname='new header/footnote')` to update a single column. Using a
+#'   Use `modify_*(colname='new header')` to update a single column. Using a
 #'   formula will invoke tidyselect, e.g. `modify_*(all_stat_cols() ~ "**{level}**")`.
 #'   The dynamic dots allow syntax like `modify_header(x, !!!list(label = "Variable"))`.
 #'   See examples below.
 #'
 #'   Use the `show_header_names()` to see the column names that can be modified.
-#' @param abbreviation (scalar `logical`)\cr
-#'   Logical indicating if an abbreviation is being updated.
 #' @param text_interpret (`string`)\cr
 #'   String indicates whether text will be interpreted with
 #'   [`gt::md()`] or [`gt::html()`]. Must be `"md"` (default) or `"html"`.
+#'   Applies to tables printed with `{gt}`.
+#' @param level (`integer`)\cr
+#'   An integer specifying which level to place the spanning header.
+#' @param columns ([`tidy-select`][dplyr::dplyr_tidy_select])\cr
+#'   Columns from which to remove spanning headers.
+#' @param show_hidden (scalar `logical`)\cr
+#'   Logical indicating whether to print hidden columns as well as printed columns.
+#'   Default is `FALSE`.
 #' @param update,quiet `r lifecycle::badge("deprecated")`
 #' @param include_example `r lifecycle::badge("deprecated")`
 #'
@@ -36,7 +40,7 @@
 #' @name modify
 #'
 #' @section `tbl_summary()`, `tbl_svysummary()`, and `tbl_cross()`:
-#' When assigning column headers, footnotes, and spanning headers,
+#' When assigning column headers and spanning headers,
 #' you may use `{N}` to insert the number of observations.
 #' `tbl_svysummary` objects additionally have `{N_unweighted}` available.
 #'
@@ -50,7 +54,7 @@
 #' you may use `{N}` to insert the number of observations, and `{N_event}`
 #' for the number of events (when applicable).
 #'
-#' @examples
+#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed(c("cardx", "broom", "broom.helpers"))
 #' # create summary table
 #' tbl <- trial |>
 #'   tbl_summary(by = trt, missing = "no", include = c("age", "grade", "trt")) |>
@@ -60,23 +64,15 @@
 #' show_header_names(tbl)
 #'
 #' # Example 1 ----------------------------------
-#' # updating column headers and footnote
+#' # updating column headers
 #' tbl |>
-#'   modify_header(label = "**Variable**", p.value = "**P**") |>
-#'   modify_footnote(all_stat_cols() ~ "median (IQR) for Age; n (%) for Grade")
+#'   modify_header(label = "**Variable**", p.value = "**P**")
 #'
 #' # Example 2 ----------------------------------
-#' # updating headers, remove all footnotes, add spanning header
+#' # updating headers add spanning header
 #' tbl |>
 #'   modify_header(all_stat_cols() ~ "**{level}**, N = {n} ({style_percent(p)}%)") |>
-#'   modify_footnote(everything() ~ NA) |>
 #'   modify_spanning_header(all_stat_cols() ~ "**Treatment Received**")
-#'
-#' # Example 3 ----------------------------------
-#' # updating an abbreviation in table footnote
-#' glm(response ~ age + grade, trial, family = binomial) |>
-#'   tbl_regression(exponentiate = TRUE) |>
-#'   modify_footnote(conf.low = "CI = Credible Interval", abbreviation = TRUE)
 NULL
 
 #' @name modify
@@ -126,69 +122,23 @@ modify_header <- function(x, ..., text_interpret = c("md", "html"),
   x
 }
 
-#' @name modify
-#' @export
-modify_footnote <- function(x, ..., abbreviation = FALSE,
-                            text_interpret = c("md", "html"),
-                            update, quiet) {
-  set_cli_abort_call()
-  updated_call_list <- c(x$call_list, list(modify_footnote = match.call()))
-
-  # checking inputs ------------------------------------------------------------
-  check_class(x, "gtsummary")
-  text_interpret <- arg_match(text_interpret)
-
-  # process inputs -------------------------------------------------------------
-  dots <- rlang::dots_list(...)
-  dots <- .deprecate_modify_update_and_quiet_args(dots, update, quiet, calling_fun = "modify_footnote")
-
-  # process arguments ----------------------------------------------------------
-  text_interpret <- rlang::arg_match(text_interpret)
-  cards::process_formula_selectors(data = scope_header(x$table_body, x$table_styling$header), dots = dots)
-  cards::check_list_elements(
-    x = dots,
-    predicate = function(x) is_string(x) || is.na(x),
-    error_msg =
-      c("All values passed in {.arg ...} must be strings.",
-        "i" = "For example, {.code label='Results as of June 26, 2015'}"
-      )
-  )
-
-  # evaluate the strings with glue
-  dots <- .evaluate_string_with_glue(x, dots)
-
-  # updating footnotes ---------------------------------------------------------
-  x <-
-    if (!abbreviation) {
-      modify_table_styling(
-        x = x,
-        columns = names(dots),
-        footnote = unlist(dots),
-        text_interpret = text_interpret
-      )
-    } else {
-      modify_table_styling(
-        x = x,
-        columns = names(dots),
-        footnote_abbrev = unlist(dots),
-        text_interpret = text_interpret
-      )
-    }
-
-  # returning gtsummary object -------------------------------------------------
-  x$call_list <- updated_call_list
-  x
-}
-
 #' @name modify
 #' @export
 modify_spanning_header <- function(x, ..., text_interpret = c("md", "html"),
+                                   level = 1L,
                                    quiet, update) {
   set_cli_abort_call()
-  updated_call_list <- c(x$call_list, list(modify_footnote = match.call()))
+  updated_call_list <- c(x$call_list, list(modify_spanning_header = match.call()))
 
   # checking inputs ------------------------------------------------------------
   check_class(x, "gtsummary")
+  check_scalar_integerish(level)
+  if (level < 1) {
+    cli::cli_abort(
+      "The {.arg level} argument must be a positive integer.",
+      call = get_cli_abort_call()
+    )
+  }
   text_interpret <- arg_match(text_interpret)
 
   # process inputs -------------------------------------------------------------
@@ -210,11 +160,13 @@ modify_spanning_header <- function(x, ..., text_interpret = c("md", "html"),
 
   # updated header meta data
   x <-
-    modify_table_styling(
+    .modify_spanning_header(
       x = x,
+      level = level,
       columns = names(dots),
       spanning_header = unlist(dots),
-      text_interpret = text_interpret
+      text_interpret = text_interpret,
+      remove = FALSE
     )
 
   # return object
@@ -224,9 +176,62 @@ modify_spanning_header <- function(x, ..., text_interpret = c("md", "html"),
 
 #' @name modify
 #' @export
-show_header_names <- function(x, include_example, quiet) {
+remove_spanning_header <- function(x, columns, level = 1L) {
+  set_cli_abort_call()
+  updated_call_list <- c(x$call_list, list(remove_spanning_header = match.call()))
+
+  # checking inputs ------------------------------------------------------------
+  check_class(x, "gtsummary")
+  check_scalar_integerish(level)
+  if (level < 1) {
+    cli::cli_abort(
+      "The {.arg level} argument must be a positive integer.",
+      call = get_cli_abort_call()
+    )
+  }
+
+  # process inputs -------------------------------------------------------------
+  cards::process_selectors(data = scope_header(x$table_body, x$table_styling$header), columns = {{ columns }})
+
+  # updated header meta data
+  x <-
+    .modify_spanning_header(
+      x = x,
+      level = level,
+      columns = columns,
+      spanning_header = rep_len(NA_character_, length.out = length(columns)),
+      remove = TRUE
+    )
+
+  # return object
+  x$call_list <- updated_call_list
+  x
+}
+
+.modify_spanning_header <- function(x, columns, spanning_header, level = 1L, text_interpret = "md", remove = FALSE) {
+  # add updates to `x$table_styling$spanning_header` ---------------------------
+  x$table_styling$spanning_header <-
+    x$table_styling$spanning_header |>
+    dplyr::bind_rows(
+      dplyr::tibble(
+        level = level,
+        column = columns,
+        spanning_header = unname(spanning_header),
+        text_interpret = paste0("gt::", text_interpret),
+        remove = remove
+      )
+    )
+
+  # return table ---------------------------------------------------------------
+  x
+}
+
+#' @name modify
+#' @export
+show_header_names <- function(x, show_hidden = FALSE, include_example, quiet) {
   # checking input -------------------------------------------------------------
   check_class(x, "gtsummary")
+  check_scalar_logical(show_hidden)
 
   # deprecated arguments -------------------------------------------------------
   if (!missing(include_example)) {
@@ -246,8 +251,11 @@ show_header_names <- function(x, include_example, quiet) {
 
   # printing info --------------------------------------------------------------
   df_print <-
-    x$table_styling$header |>
-    dplyr::filter(!.data$hide) |>
+    x$table_styling$header %>%
+    {case_switch(
+      !show_hidden ~ dplyr::filter(., !.data$hide),
+      .default = dplyr::mutate(., column = ifelse(.data$hide, paste0(.data$column, "\U2020"), .data$column))
+    )} |>
     dplyr::select("column", "label", starts_with("modify_stat_"))
 
   # save column class abbreviations
@@ -297,10 +305,16 @@ show_header_names <- function(x, include_example, quiet) {
 
   tibble_as_cli(df_print, label = list(column = "Column Name", label = "Header"))
 
+  msg <-
+    c("* These values may be dynamically placed into headers (and other locations).",
+      "i" = "Review the {.help [{.fun modify_header}](gtsummary::modify_header)} help for examples."
+    )
+  if (show_hidden) {
+    msg <- append(msg, values = "\U2020 Hidden columns", after = 2)
+  }
+
   cat("\n")
-  cli::cli_inform(c("* These values may be dynamically placed into headers (and other locations).",
-    "i" = "Review the {.help [{.fun modify_header}](gtsummary::modify_header)} help for examples."
-  ))
+  cli::cli_inform(message = msg)
 }
 
 .get_class_abbreviation <- function(x) {
