@@ -1,4 +1,5 @@
-skip_if_not(is_pkg_installed(c("broom", "lme4", "broom.helpers"), reference_pkg = "cardx"))
+skip_on_cran()
+skip_if_not(is_pkg_installed(c("broom", "lme4", "broom.helpers"), ref = "cardx"))
 
 test_that("add_p.tbl_summary() snapshots of common outputs", {
   expect_snapshot(
@@ -63,7 +64,7 @@ test_that("add_p.tbl_summary() error messaging with bad inputs", {
 })
 
 test_that("add_p.tbl_summary() & lme4", {
-  skip_if_not(is_pkg_installed("lme4", reference_pkg = "cardx"))
+  skip_if_not(is_pkg_installed("lme4", ref = "cardx"))
 
   # errors with expected use
   expect_snapshot(
@@ -382,7 +383,7 @@ test_that("p-values are replicated within tbl_summary() with groups", {
 })
 
 test_that("Groups arg and lme4", {
-  skip_if_not(is_pkg_installed(c("lme4", "broom.mixed"), reference_pkg = "cardx"))
+  skip_if_not(is_pkg_installed(c("lme4", "broom.mixed"), ref = "cardx"))
   withr::local_package("broom")
   withr::local_package("lme4")
 
@@ -436,6 +437,8 @@ test_that("no error with missing data", {
 })
 
 test_that("add_p.tbl_summary() can be run after add_difference()", {
+  skip_if_not(is_pkg_installed("parameters"))
+
   expect_error(
     trial |>
       select(age, trt) |>
