@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("huxtable"))
+skip_if_not(is_pkg_installed(c("huxtable", "withr")))
 
 my_tbl_summary <- trial |>
   select(trt, age, death) |>
@@ -25,13 +25,15 @@ test_that("as_hux_table(return_calls) works as expected", {
   # correct elements are returned
   expect_equal(
     names(ht),
-    c("tibble", "fmt", "cols_merge", "cols_hide", "huxtable", "set_left_padding", "add_footnote", "source_note",
-      "set_bold", "set_italic", "fmt_missing", "insert_row", "set_markdown", "align", "set_number_format")
+    c("tibble", "fmt", "cols_merge", "cols_hide", "huxtable", "set_left_padding",
+      "add_footnote", "abbreviations", "source_note", "set_bold", "set_italic",
+      "fmt_missing", "insert_row", "set_markdown", "align", "set_number_format")
   )
 })
 
 test_that("as_hux_table works with tbl_merge", {
   skip_if_not(is_pkg_installed("survival"))
+  withr::local_options(list(width = 120))
 
   t1 <- glm(response ~ trt + grade + age, trial, family = binomial) |>
     tbl_regression(exponentiate = TRUE)
@@ -48,6 +50,31 @@ test_that("as_hux_table works with tbl_merge", {
   expect_snapshot(ht_merge)
 })
 
+test_that("as_hux_table checking the placement of a second spanning header", {
+  expect_silent(
+    tbl2 <-
+      trial |>
+      tbl_summary(by = grade, include = age) |>
+      modify_spanning_header(c(stat_1, stat_3) ~ "**Testing**") |>
+      modify_spanning_header(all_stat_cols() ~ "**Tumor Grade**", level = 2) |>
+      as_hux_table()
+  )
+
+  expect_equal(
+    map(tbl2, ~.x[1:3]) |>
+      dplyr::bind_cols() |>
+      as.data.frame(),
+    data.frame(
+      stringsAsFactors = FALSE,
+      label = c(NA, NA, "**Characteristic**"),
+      stat_1 = c("**Tumor Grade**", "**Testing**", "**I**  \nN = 68"),
+      stat_2 = c("**Tumor Grade**", NA, "**II**  \nN = 68"),
+      stat_3 = c("**Tumor Grade**", "**Testing**", "**III**  \nN = 64")
+    )
+  )
+})
+
+
 test_that("as_hux_table works with tbl_stack", {
   t1 <- trial |>
     dplyr::filter(trt == "Drug A") |>
@@ -108,9 +135,9 @@ test_that("as_hux_table passes table column alignment correctly", {
   )
 })
 
-test_that("as_hux_table passes table footnotes & footnote abbreviations correctly", {
+test_that("as_hux_table passes table footnotes & abbreviations correctly", {
   tbl_fn <- my_tbl_summary |>
-    modify_table_styling(columns = label, footnote = "test footnote", rows = variable == "age")
+    modify_footnote_body(columns = label, footnote = "test footnote", rows = variable == "age")
   ht_fn <- tbl_fn |> as_hux_table()
 
   # footnote
@@ -124,27 +151,36 @@ test_that("as_hux_table passes table footnotes & footnote abbreviations correctl
   )
 
   tbl_fa <- tbl_fn |>
-    modify_footnote(stat_0 = "N = number of observations", abbreviation = TRUE)
+    modify_abbreviation("N = number of observations")
   ht_fa <- tbl_fa |> as_hux_table()
 
   # footnote_abbrev
   expect_equal(
-    ht_fa[9, 1] |> unlist(use.names = FALSE),
-    "N = number of observations"
+    ht_fa[10, 1] |> unlist(use.names = FALSE),
+    "Abbreviation: N = number of observations"
   )
 
   # customized footnotes
   tbl <- my_tbl_summary |>
-    modify_footnote(
-      all_stat_cols() ~ "replace old footnote",
-      label = "another new footnote"
-    )
+    modify_footnote_header("replace old footnote", columns = all_stat_cols()) |>
+    modify_footnote_header("another new footnote", columns = label)
+
   ht <- tbl |> as_hux_table()
 
   expect_equal(
     ht[8:9, 1] |> unlist(use.names = FALSE),
     c("another new footnote", "replace old footnote")
   )
+
+  expect_equal(
+    my_tbl_summary |>
+      modify_footnote_spanning_header("footnote test", columns = all_stat_cols()) |>
+      as_hux_table() %>%
+      `[`(8,) |>
+      unlist() |>
+      unname(),
+    c("footnote test", "footnote test")
+  )
 })
 
 test_that("as_hux_table passes appended glance statistics correctly", {
@@ -162,7 +198,7 @@ test_that("as_hux_table passes appended glance statistics correctly", {
   # correct row ordering
   expect_equal(
     ht$label,
-    c("**Characteristic**", "Age", "R²", "BIC", "CI = Confidence Interval", "R² = 0.000; BIC = 471")
+    c("**Characteristic**", "Age", "R²", "BIC", "Abbreviation: CI = Confidence Interval", "R² = 0.000; BIC = 471")
   )
 })
 
@@ -207,7 +243,7 @@ test_that("as_hux_table passes missing symbols correctly", {
 
   # specify missing symbol
   tbl <- tbl |>
-    modify_table_styling(stat_0, rows = !is.na(label), missing_symbol = "n / a")
+    modify_missing_symbol(stat_0, rows = !is.na(label), symbol = "n / a")
   ht <- tbl |> as_hux_table()
 
   # correct substitution for missing values
