@@ -151,14 +151,13 @@ test_that("combine_terms works with GEE models", {
 test_that("combine_terms works when used in map/apply", {
   data <- data.frame(outcome = "marker", exp = FALSE, test = "F")
 
-  expect_no_error(
+  expect_silent(
     res <- data |>
       mutate(
         mod = map(outcome, ~ glm(as.formula(paste0(.x, " ~ age + stage")), data = trial, family = gaussian)),
         tbl = map2(mod, exp, ~ tbl_regression(.x, exponentiate = .y)),
         tbl2 = map2(tbl, test, ~ combine_terms(..1, formula_update = . ~ . - stage, test = ..2))
-      ) |>
-      invisible()
+      )
   )
 })
 
